@@ -1,7 +1,9 @@
-from IPython import embed
-from ploomber.cli.parsers import CustomParser, _custom_command
+from IPython import start_ipython
+from ploomber.cli.parsers import CustomParser
+from ploomber.cli.io import cli_endpoint
 
 
+@cli_endpoint
 def main():
     parser = CustomParser(description='Call an entry point '
                           '(pipeline.yaml or dotted path to factory)')
@@ -9,7 +11,7 @@ def main():
         # this command has no static args
         pass
 
-    dag, args = _custom_command(parser)
+    dag, _ = parser.load_from_entry_point_arg()
 
     try:
         dag.render()
@@ -17,7 +19,6 @@ def main():
         print('Your dag failed to render, but you can still inspect the '
               'object to debug it.\n')
 
-    del parser
-    del args
-
-    embed(colors='neutral')
+    # NOTE: do not use embed here, we must use start_ipytho, see here:
+    # https://github.com/ipython/ipython/issues/8918
+    start_ipython(argv=[], user_ns={'dag': dag})
