@@ -166,6 +166,16 @@ class CustomParser(argparse.ArgumentParser):
 
         return dag, args
 
+    def load_from_entry_point_arg(self):
+        """Parses an entry point, adding arguments by extracting them from the env.
+
+        Returns a dag and the parsed args
+        """
+        entry_point = EntryPoint(self.parse_entry_point_value())
+        dag, args = load_dag_from_entry_point_and_parser(entry_point, self,
+                                                         sys.argv)
+        return dag, args
+
 
 def _path_for_module_path(module_path):
     mod_name, path_part = module_path.split('::')
@@ -394,19 +404,6 @@ def _process_file_dir_or_glob(parser, dagspec_arg=None):
     return dag, args
 
 
-# FIXME: I think this is always used with CustomParser, we should make it
-# and instance method instead
-def _custom_command(parser):
-    """
-    Parses an entry point, adding arguments by extracting them from the env.
-    Returns a dag and the parsed args
-    """
-    entry_point = EntryPoint(parser.parse_entry_point_value())
-    dag, args = load_dag_from_entry_point_and_parser(entry_point, parser,
-                                                     sys.argv)
-    return dag, args
-
-
 def load_dag_from_entry_point_and_parser(entry_point, parser, argv):
     """Load DAG from entry point
 
