@@ -1,4 +1,4 @@
-from ploomber.cli.parsers import _custom_command, CustomParser
+from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 
 
@@ -8,5 +8,5 @@ def main():
     with parser:
         # this command has no static args
         pass
-    dag, args = _custom_command(parser)
+    dag, args = parser.load_from_entry_point_arg()
     print(dag.status())
