@@ -1,4 +1,4 @@
-from ploomber.cli.parsers import _custom_command, CustomParser
+from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 
 # TODO: we are just smoke testing this, we need to improve the tests
@@ -21,7 +21,7 @@ def main():
             action='store_true')
         parser.add_argument('--force',
                             '-f',
-                            help='Force build task (ignore up-to-date status)',
+                            help='Force task build (ignore up-to-date status)',
                             action='store_true')
         parser.add_argument('--status',
                             '-st',
@@ -31,9 +31,9 @@ def main():
                             '-of',
                             help='Only execute on_finish hook',
                             action='store_true')
-    dag, args = _custom_command(parser)
+    dag, args = parser.load_from_entry_point_arg()
 
-    dag.render(force=args.force)
+    dag.render()
     task = dag[args.task_name]
 
     if args.source:
@@ -48,5 +48,6 @@ def main():
     # task if build by default, but when --source or --status are passed,
     # the --build flag is required
     no_flags = not any((args.build, args.status, args.source, args.on_finish))
+
     if no_flags or args.build:
         task.build(force=args.force)
