@@ -7,6 +7,7 @@ from copy import deepcopy, copy
 from collections.abc import Mapping, Iterable
 from pathlib import Path
 from functools import reduce
+import datetime
 
 from jinja2 import Template, StrictUndefined
 
@@ -263,6 +264,11 @@ class EnvironmentExpander:
 
         return repo.get_git_info(module)['git_location']
 
+    def get_now(self):
+        """Returns current timestamp in ISO 8601 format
+        """
+        return datetime.datetime.now().isoformat()
+
 
 def iterate_nested_dict(d):
     """
